@@ -722,7 +722,7 @@ Args:
 Returns:
     TextContent: Contains the result image URL or file path
 """)
-async def gbu_remove_bg(
+async def remove_bg(
     image_url: str,
 ) -> TextContent:
     try:
@@ -760,7 +760,7 @@ Args:
 Returns:
     TextContent: Contains the result image URL or file path
 """)
-async def gbu_hd_restore(
+async def hd_restore(
     image_url: str,
 ) -> TextContent:
     try:
@@ -944,7 +944,7 @@ async def openai_edit_image(
 
 
 @mcp.tool()
-async def gbu_japanese_tts(
+async def japanese_tts(
     text: str,
     format: str = "mp3",
     sample_rate: int = 16000,
@@ -992,7 +992,7 @@ async def gbu_japanese_tts(
         )
 
 @mcp.tool()
-async def gbu_ai_search(
+async def ai_search(
     query: str,
     search_engine: str = "Google",
     llm_name: str = "gpt4o", 
@@ -1518,30 +1518,38 @@ async def kling_query_ttv_task(
     Args:
         prompt (str): The prompt describing the anime character to generate,only support English.
         gender (str): The gender of the anime character to generate. 0-male, 1-female, 2-other
-        model_style (str): The style of the anime character to generate. values range: ["Games", "Series", "Manhwa", "Comic", "Illustration"],
-            notes: Games-游戏, Series-番剧, Manhwa-韩漫, Comic-漫画专用, Illustration-插画,
+        model_style (str): The style of the comic image. value range: ["Games", "Series", "Manhwa", "Comic", "Illustration"],
+            notes: The following shows each model_style's corresponding Chinese and Japanese expressions:
+            Games(游戏 / ゲーム), Series(番剧 / TVアニメ), Manhwa(韩漫 / 韓国漫画), Comic(漫画专用 / カラフル), Illustration(插画 / イラスト)
+        index (int, optional): Sequential index for tracking generation order when LLM calls this tool multiple times. Starts from 1. Useful for batch processing and result ordering.
+        max_retries (int, optional): Maximum number of retries for task polling. Default is 50.
+        retry_interval (int, optional): Interval in seconds between task polling attempts. Default is 2.
 
     Returns:
-        task_id (str): The task ID of the anime character generation task.
+        TextContent: Contains the generated image content and metadata
 """)
-async def gbu_ugc_tti(
+async def ugc_tti(
     prompt: str,
     gender: int,
     model_style: str,
-    max_retries: int = 10,
-    retry_interval: int = 5
+    index: int = 1,
+    max_retries: int = 50,
+    retry_interval: int = 2
 ) -> TextContent:
     try:
         model_style_mapping = {
-            "Games": "onediff_v1_animagine-xl-3.1.safetensors", 
-            
+            "Games": "ugc_image_animagine", 
+            "Series": "ugc_image_animeseries",
+            "Manhwa": "ugc_image_koreanComics",
+            "Comic": "ugc_image_illlustrious",
+            "Illustration": "ugc_image_awpainting",
         }
-        model_name = model_style_mapping.get(model_style, "Games")
+        model_tag = model_style_mapping.get(model_style, "comic_image_waiNSFWv1")
 
         data = {
             "prompt": prompt,
             "gender": gender,
-            "model_name": model_name
+            "template_tag": model_tag
         }
 
         response_data = await make_unified_request(
@@ -1552,6 +1560,7 @@ async def gbu_ugc_tti(
         
         # get task_id, and start polling task status
         task_id = response_data.get("data", {}).get("task_id")
+        cost_points = response_data.get("data", {}).get("cost_points")
         if not task_id:
             raise Exception("Task ID is not found")
         
@@ -1565,22 +1574,72 @@ async def gbu_ugc_tti(
 
             errno = task_response.get('errno')
             if errno == 0: 
+                img_data = task_response.get("data", {}).get("img_data", [])
+                images = []
+                for item in img_data:
+                    item_images = item.get('images', [])
+                    for img in item_images:
+                        if img.get('webp'):
+                            images.append({
+                                'url': img['webp'],
+                                'format': 'webp'
+                            })
+
+                final_result = {
+                    "task_id": task_id,
+                    "status": "generation success",
+                    "msg": task_response.get('msg', ''),
+                    "cost_points": cost_points,
+                    "input_parameters": data,
+                    "generated_images": images,
+                    "index": index,
+                }
                 return TextContent(
                     type="text",
-                    text=f"Success. Anime character generation completed: {task_response}"
+                    text=f"{final_result}"
                 )
             elif errno not in [0, 2200]: #2200，task is running
-                raise Exception(f"Anime character generation task failed for task_id: {task_id}")       
+                final_result = {
+                    "task_id": task_id,
+                    "status": "generation failed",
+                    "msg": task_response.get('msg', ''),
+                    "cost_points": cost_points,
+                    "input_parameters": data,
+                    "index": index,
+                }
+                return TextContent(
+                    type="text",
+                    text=f"{final_result}"
+                )
             
             # Wait before retrying
             await asyncio.sleep(retry_interval)
 
-        raise Exception(f"Anime character generation task did not complete in time for task_id: {task_id}")
-
-    except Exception as e:
+        final_result = {
+            "task_id": task_id,
+            "status": "generation failed",
+            "msg": "Anime character generation task did not complete in time",
+            "cost_points": cost_points,
+            "input_parameters": data,
+            "index": index,
+        }
         return TextContent(
             type="text",
-            text=f"Failed to generate and query anime character: {str(e)}"
+            text=f"{final_result}"
+        )
+
+    except Exception as e:
+        final_result = {
+            "task_id": task_id,
+            "status": "generation failed",
+            "msg": f"Failed to generate and query anime character: {str(e)}",
+            "cost_points": cost_points,
+            "input_parameters": data,
+            "index": index,
+        }
+        return TextContent(
+            type="text",
+            text=f"{final_result}"
         )
 
 
@@ -1591,13 +1650,19 @@ async def gbu_ugc_tti(
 
     Args:
         image_url (str): The URL of the character image.
+        index (int, optional): Sequential index for tracking generation order when LLM calls this tool multiple times. Starts from 1. Useful for batch processing and result ordering.
+        max_retries (int, optional): Maximum number of retries for task polling. Default is 20.
+        retry_interval (int, optional): Interval in seconds between task polling attempts. Default is 3.
+        
+        
 
     Returns:
-        task_id (str): The task ID of the pose align image generation task.
+        TextContent: Contains the generated image content and metadata
 """)
-async def gbu_anime_pose_align(
+async def anime_pose_align(
     image_url: str,
-    max_retries: int = 10,
+    index: int = 1,
+    max_retries: int = 20,
     retry_interval: int = 3
 ) -> TextContent:
     try:
@@ -1616,6 +1681,7 @@ async def gbu_anime_pose_align(
         
         # get task_id, and start polling task status
         task_id = response_data.get("data", {}).get("task_id")
+        cost_points = response_data.get("data", {}).get("cost_points")
         if not task_id:
             raise Exception("Task ID is not found")
         
@@ -1629,22 +1695,72 @@ async def gbu_anime_pose_align(
             
             errno = task_response.get('errno')
             if errno == 0: 
+                img_data = task_response.get("data", {}).get("img_data", [])
+                images = []
+                for item in img_data:
+                    item_images = item.get('images', [])
+                    for img in item_images:
+                        if img.get('webp'):
+                            images.append({
+                                'url': img['webp'],
+                                'format': 'webp'
+                            })
+
+                final_result = {
+                    "task_id": task_id,
+                    "status": "generation success",
+                    "msg": task_response.get('msg', ''),
+                    "cost_points": cost_points,
+                    "input_parameters": data,
+                    "generated_images": images,
+                    "index": index,
+                }
                 return TextContent(
                     type="text",
-                    text=f"Success. Pose align task completed: {task_response}"
+                    text=f"{final_result}"
+                )
+            elif errno not in [0, 2200]: #task failed(2200-task is running)
+                final_result = {
+                    "task_id": task_id,
+                    "status": "generation failed",
+                    "msg": task_response.get('msg', ''),
+                    "cost_points": cost_points,
+                    "input_parameters": data,
+                    "index": index,
+                }
+                return TextContent(
+                    type="text",
+                    text=f"{final_result}"
                 )
-            elif errno not in [0, 2200]: #2200，task is running
-                raise Exception(f"Pose align task failed for task_id: {task_id}")       
 
             # Wait before retrying
             await asyncio.sleep(retry_interval)
 
-        raise Exception(f"Pose align task did not complete in time for task_id: {task_id}")
-
-    except Exception as e:
+        final_result = {
+            "task_id": task_id,
+            "status": "generation failed",
+            "msg": "Pose align task did not complete in time",
+            "cost_points": cost_points,
+            "input_parameters": data,
+            "index": index,
+        }
         return TextContent(
             type="text",
-            text=f"Failed to generate and query pose align: {str(e)}"
+            text=f"{final_result}"
+        )
+
+    except Exception as e:
+        final_result = {
+            "task_id": task_id,
+            "status": "generation failed",
+            "msg": f"Failed to generate and query pose align: {str(e)}",
+            "cost_points": cost_points,
+            "input_parameters": data,
+            "index": index,
+            }
+        return TextContent(
+            type="text",
+            text=f"{final_result}"
         )
 
 
@@ -1659,13 +1775,17 @@ async def gbu_anime_pose_align(
         char2_image (str): The URL of the character2 image pose align. value = "" if scene_type in ["nc", "single"]
         char1_gender (str): The gender of the character1. value range: ["0", "1"], 0-male,1-female
         char2_gender (str): The gender of the character2. value range: ["0", "1"], 0-male,1-female, value = "" if scene_type in ["nc", "single"]
-            model_style (str): The style of the comic image. value range: ["Games", "Series", "Manhwa", "Comic", "Illustration"],
-                notes: Games-游戏, Series-番剧, Manhwa-韩漫, Comic-漫画专用, Illustration-插画,
+        model_style (str): The style of the comic image. value range: ["Games", "Series", "Manhwa", "Comic", "Illustration"],
+            notes: The following shows each model_style's corresponding Chinese and Japanese expressions:
+            Games(游戏 / ゲーム), Series(番剧 / TVアニメ), Manhwa(韩漫 / 韓国漫画), Comic(漫画专用 / カラフル), Illustration(插画 / イラスト)
+        index (int, optional): Sequential index for tracking generation order when LLM calls this tool multiple times. Starts from 1. Useful for batch processing and result ordering.
+        max_retries (int, optional): Maximum number of retries for task polling. Default is 50.
+        retry_interval (int, optional): Interval in seconds between task polling attempts. Default is 2.
 
     Returns:
-        task_id (str): The task ID of the comic image generation task.
+        TextContent: Contains the generated image content and metadata
 """)
-async def gbu_anime_comic_image(
+async def anime_comic_image(
     prompt: str,
     scene_type: str,
     char1_image: str,
@@ -1673,18 +1793,23 @@ async def gbu_anime_comic_image(
     char1_gender: str,
     char2_gender: str,
     model_style: str,
-    max_retries: int = 10,
-    retry_interval: int = 10        
+    index: int = 1,
+    max_retries: int = 50,
+    retry_interval: int = 2       
 ) -> TextContent:
     try:
         char2_image = "" if scene_type in ["nc", "single"] else char2_image
         char2_gender = "" if scene_type in ["nc", "single"] else char2_gender
 
         model_style_mapping = {
-            "Games": "onediff_v1_animagine-xl-3.1.safetensors", 
+            "Games": "comic_image_animagine", 
+            "Series": "comic_image_animeseries",
+            "Manhwa": "comic_image_koreanComics",
+            "Comic": "comic_image_waiNSFWv1",
+            "Illustration": "comic_image_awpainting",
             
         }
-        model_name = model_style_mapping.get(model_style, "Games")
+        model_tag = model_style_mapping.get(model_style, "comic_image_waiNSFWv1")
 
         data = {
             "prompt": prompt,
@@ -1693,7 +1818,7 @@ async def gbu_anime_comic_image(
             "char2_image": char2_image,
             "char1_gender": char1_gender,
             "char2_gender": char2_gender,
-            "model_name": model_name,
+            "template_tag": model_tag,
         }
 
         response_data = await make_unified_request(
@@ -1704,6 +1829,7 @@ async def gbu_anime_comic_image(
         
         # get task_id, and start polling task status
         task_id = response_data.get("data", {}).get("task_id")
+        cost_points = response_data.get("data", {}).get("cost_points")
         if not task_id:
             raise Exception("Task ID is not found")
         
@@ -1714,26 +1840,76 @@ async def gbu_anime_comic_image(
                 path=f"/pulsar/mcp/inner/comic/query_task",
                 data={"task_id": task_id},
             )
-            
+
             errno = task_response.get('errno')
-            if errno == 0:
+            if errno == 0:  # generation success      
+                img_data = task_response.get("data", {}).get("img_data", [])
+                images = []
+                for item in img_data:
+                    item_images = item.get('images', [])
+                    for img in item_images:
+                        if img.get('webp'):
+                            images.append({
+                                'url': img['webp'],
+                                'format': 'webp'
+                            })
+                
+                final_result = {
+                    "task_id": task_id,
+                    "status": "generation success",
+                    "msg": task_response.get('msg', ''),
+                    "cost_points": cost_points,
+                    "input_parameters": data,
+                    "generated_images": images,
+                    "index": index,
+                }
                     
-                    return TextContent(
+                return TextContent(
+                type="text",
+                text=f"{final_result}"
+            )
+            elif errno not in [0, 2200]: #task failed(2200-task is running)
+                final_result = {
+                    "task_id": task_id,
+                    "status": "generation failed",
+                    "msg": task_response.get('msg', ''),
+                    "cost_points": cost_points,
+                    "input_parameters": data,
+                    "index": index,
+                }
+                return TextContent(
                     type="text",
-                    text=f"Success. Comic image generation task completed: {task_response}"
+                    text=f"{final_result}"
                 )
-            elif errno not in [0, 2200]: #2200，task is running
-                raise Exception(f"Comic image generation task failed for task_id: {task_id}")       
 
             # Wait before retrying
             await asyncio.sleep(retry_interval)
-
-        raise Exception(f"Comic image generation task did not complete in time for task_id: {task_id}")
+        
+        final_result = {
+            "task_id": task_id,
+            "status": "generation failed",
+            "msg": "Comic image generation task did not complete in time",
+            "cost_points": cost_points,
+            "input_parameters": data,
+            "index": index,
+        }
+        return TextContent(
+            type="text",
+            text=f"{final_result}"
+        )
     
     except Exception as e:
+        final_result = {
+            "task_id": task_id,
+            "status": "generation failed",
+            "msg": f"Failed to create comic image generation task: {str(e)}",
+            "cost_points": cost_points,
+            "input_parameters": data,
+            "index": index,
+        }
         return TextContent( 
             type="text",
-            text=f"Failed to create comic image generation task: {str(e)}"
+            text=f"{final_result}"
         )
 
 
@@ -1747,7 +1923,7 @@ async def gbu_anime_comic_image(
     Returns:
         TextContent: Contains the generated comic script content
 """)
-async def gbu_generate_comic_story(
+async def generate_comic_story(
     topic_input: str
 ) -> TextContent:
     try:
@@ -1784,13 +1960,13 @@ async def gbu_generate_comic_story(
     Args:
         input_novel (str): The novel input, required.
         chars_info (str or dict): The characters info. Supports both dictionary objects and JSON strings.
-                          Example: {"char1": {"name": "Jack", "gender": "male"}, "char2": {"name": "Mary", "gender": "female"}}
+            Example: {"char1": {"name": "Jack", "gender": "male"}, "char2": {"name": "Mary", "gender": "female"}}
         chapters_num (int): The number of chapters to generate, default is 4, max is 15.
 
     Returns:
         TextContent: Contains the generated comic story chapters content
 """)
-async def gbu_generate_comic_chapters(
+async def generate_comic_chapters(
     input_novel: str,
     chars_info: Union[str, dict],
     chapters_num: int = 10
@@ -1842,13 +2018,13 @@ async def gbu_generate_comic_chapters(
 @mcp.tool(description="""
     Function: Generate image prompts based on comic story chapter and character info.
     Args:
-        input_chapters (str or dict): The comic story chapter input (text分镜结构体), required.
+        input_chapters (str or dict): The comic story chapter input, required.
         chars_info (str or dict): The characters info. Supports both dictionary objects and JSON strings.
                           Example: {"char1": {"name": "Jack", "gender": "male"}, "char2": {"name": "Mary", "gender": "female"}}
     Returns:
-        TextContent: Contains the generated image prompts content
+        TextContent: Contains the  image prompts content for comic image generation
 """)
-async def gbu_generate_comic_image_prompts(
+async def generate_comic_image_prompts(
     input_chapters: Union[str, dict],
     chars_info: Union[str, dict],
 ) -> TextContent:
@@ -1909,7 +2085,7 @@ async def gbu_generate_comic_image_prompts(
     Returns:
         TextContent: Contains the generated image content
 """)
-async def gbu_flux_edit_image(
+async def flux_edit_image(
     image_url: str,
     image_prompt: str,
     max_retries: int = 20,
@@ -1965,9 +2141,112 @@ async def gbu_flux_edit_image(
         )
 
 
+@mcp.tool(description="""
+    Function: edit comic story based on edit prompt and input story.
+    Args:
+        edit_prompt (str): The edit prompt for the comic story, required.
+        input_story (str or dict): The input story, required.including story content and story title.format example:{"story_title": "xxx", "story": "xxx"}
+                          
+    Returns:
+        TextContent: Contains the generated comic story content
+""")
+async def edit_comic_story(
+    edit_prompt: str,
+    input_story: Union[str, dict],
+) -> TextContent:
+    try:
+        if not edit_prompt:
+            raise Exception("edit_prompt is required")
+        if not input_story:
+            raise Exception("input_story is required")
+        
+        if isinstance(input_story, str):
+            input_story = json.loads(input_story)
+        elif isinstance(input_story, dict):
+            input_story = input_story
+        else:
+            raise Exception("input_story must be a dictionary or JSON string") 
+        
+        input_story_json = json.dumps(input_story, ensure_ascii=False)
+
+        payload = {
+            "story_input": input_story_json,
+            "edit_prompt": edit_prompt
+        }
+        
+        response_data = await make_unified_request(
+            method="POST",
+            path="/pulsar/mcp/inner/comic/edit_script",
+            data=payload,
+            stream=True
+        )
+        
+        
+        return TextContent(
+            type="text",
+            text=response_data
+        )
+        
+    except Exception as e:
+        return TextContent(
+            type="text",
+            text=f"failed to edit comic story: {str(e)}"
+        )
 
 
+@mcp.tool(description="""
+    Function: edit comic chapters based on edit prompt and input chapters.
+    Args:
+        edit_prompt (str): The edit prompt for the comic chapters, required.
+        input_chapters (str or dict): The input chapters, required.Format example:
+        {"title": "chapter_title", "chapter_image": {"1": {"description": "scene_desc", "dialogue": [{"name": "char_name", "text": "dialogue_text"}], "aside": "aside_text"}}}
+                          
+                          
+    Returns:
+        TextContent: Contains the generated comic chapters content
+""")
+async def edit_comic_chapters(
+    edit_prompt: str,
+    input_chapters: Union[str, dict],
+) -> TextContent:
+    try:
+        if not edit_prompt:
+            raise Exception("edit_prompt is required")
+        if not input_chapters:
+            raise Exception("input_chapters is required")
+        
+        if isinstance(input_chapters, str):
+            input_chapters = json.loads(input_chapters)
+        elif isinstance(input_chapters, dict):
+            input_chapters = input_chapters
+        else:
+            raise Exception("input_chapters must be a dictionary or JSON string") 
+        
+        input_chapters_json = json.dumps(input_chapters, ensure_ascii=False)
 
+        payload = {
+            "chapters_description_input": input_chapters_json,
+            "edit_prompt": edit_prompt
+        }
+        
+        response_data = await make_unified_request(
+            method="POST",
+            path="/pulsar/mcp/inner/comic/edit_storyboards",
+            data=payload,
+            stream=True
+        )
+        
+        
+        return TextContent(
+            type="text",
+            text=response_data
+        )
+        
+    except Exception as e:
+        return TextContent(
+            type="text",
+            text=f"failed to edit comic chapters: {str(e)}"
+        )
 
 
 def main():
